import requests
import json

class ID(object):
    def __init__(self, ids):
        self.ids = ids

    def id_get(self):
        all_data = {}
        for event_id in self.ids:
            url = f'https://api.fda.gov/food/enforcement.json?search=event_id:"{event_id}"'
            response = requests.get(url)

            if response.ok:
                all_data[event_id] = response.json()
            else:
                all_data[event_id] = "Error: " + response.text

        with open("food_reverse_id.json", "w") as outfile:
            json.dump(all_data, outfile, indent = 4) 




from date import Date

def test_date_info(start, end, limit):
    try:
        date_instance = Date(start, end, limit)
        date_instance.date_get()
    except ValueError as e:
        print(e)

test_date_info(start = 20150708, end = 20151225, limit = 5)


from city import City

def test_city_info(cities, limit):
    try:
        city_instance = City(cities, limit)
        city_instance.city_get()
        print(f"Data for city {cities} with limit {limit} has been fetched.")
    except ValueError as e:
        print(e)

test_city_info(cities = ["Austin", "New York"], limit = 3)



import requests
import json

class City(object):
    def __init__(self, cities, limit):
        self.cities = cities
        self.limit = limit

    def city_get(self):
        all_data = {}
        for city in self.cities:
            url = f'https://api.fda.gov/food/enforcement.json?search=city:{city}&limit={self.limit}'
            response = requests.get(url)
        
            if response.ok:
                all_data[city] = response.json()
            else:
                all_data[city] = "Error: " + response.text

        with open("food_reverse_city.json", "w") as outfile:
            json.dump(all_data, outfile, indent = 4)



import requests
import json

class Date(object):
    def __init__(self, start, end, limit):
        self.start = start
        self.end = end 
        self.limit = limit 

    def date_get(self):
        url = f'https://api.fda.gov/food/enforcement.json?search=report_date:[{self.start}+TO+{self.end}]&limit={self.limit}'
        response = requests.get(url)
        
        if response.ok:
            with open("food_reverse_date.json", "w") as outfile:
                json.dump(response.json(), outfile, indent = 4)
        else:
            print(f"Error: {response.status_code} - {response.text}")
